#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.15
visibility:           public
id:                   arch-hs-0.15-F1JDh9cCUIkJfhpDDTCw6A
key:                  arch-hs-0.15-F1JDh9cCUIkJfhpDDTCw6A
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  4486b77ed2415f21f91b995b8c732a0e
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.DepCheck
    Distribution.ArchHs.Exception Distribution.ArchHs.ExtraDB
    Distribution.ArchHs.FilesDB Distribution.ArchHs.Hackage
    Distribution.ArchHs.Internal.Prelude Distribution.ArchHs.Local
    Distribution.ArchHs.Name Distribution.ArchHs.Options
    Distribution.ArchHs.PP Distribution.ArchHs.PkgBuild
    Distribution.ArchHs.PkgDesc Distribution.ArchHs.RDepCheck
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/arch-hs-0.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arch-hs-0.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.15-F1JDh9cCUIkJfhpDDTCw6A
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.15/include
depends:
    Cabal-3.10.3.0 Diff-1.0-38Pk9ggjoQQ3bTSUZHJGAf
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    algebraic-graphs-0.8-1QXcJeqL7Q21Zkm9es4q7X
    arch-web-0.3.2-J8SeYUkok1iIhRyKv6kBfL base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq
    conduit-extra-1.3.8-8C1YMRPmMt82mJiP8UVrWz containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    hackage-db-2.1.3-H4k2WCy5Wxi54FTfRyQNKP
    http-client-0.7.19-4FCJ2m94wUmJsssaVohngD
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    megaparsec-9.7.1-lfMyUtNLhmEXQ4ic9tvxz
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    neat-interpolation-0.5.1.4-1wdgBCXenFOjCEnpiBYYK
    optparse-simple-0.1.1.4-GVDdiishQIyGTa9d3ZHvyy
    polysemy-1.9.2.0-B26iylKbTwp3BWPK1VEre5
    prettyprinter-1.7.2-CIJHFVXNQ7ULgjXbroiIfc
    prettyprinter-ansi-terminal-1.1.4-IGpSNms5NRqAM6mSMhvACs
    servant-client-0.20.3.0-IzR6UPxDKBe5OyvgQbPJk1
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    tar-conduit-0.4.1-1KpNU44ibwn3lNJVOopznX template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

